==> owncloud-10.2.0.zip: owncloud/apps/files/l10n/bg_BG.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Съхраняването е временно деактивирано",
    "Storage invalid" : "Невалидно дисково устройство.",
    "Unknown error" : "Непозната грешка.",
    "All files" : "Всички файлове",
    "Saved" : "Запазено",
    "File could not be found" : "Файлът не може да бъде открит",
    "Home" : "Домашен",
    "Close" : "Затвори",
    "Favorites" : "Любими",
    "Could not create folder \"{dir}\"" : "Неуспешно създаване на \"{dir}\"",
    "Upload cancelled." : "Качването е прекъснато.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неуспешно качване на {filename}, защото е директория или е с размер от 0 байта.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Няма достатъчно свободно място, ти се опитваш да качиш {size1}, но са останали само {size2}.",
    "Target folder \"{dir}\" does not exist any more" : "Целевата папка \"{dir}\" вече не съществува.",
    "Not enough free space" : "Няма достатъчно свободно пространство",
    "Uploading..." : "Качване...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} от {totalSize} ({bitrate})",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Извършва се качване на файлове. Затварянето на тази страница ще прекъсне качването.",
    "Actions" : "Действия",
    "Download" : "Изтегли",
    "Rename" : "Преименуване",
    "Delete" : "Изтрий",
    "Disconnect storage" : "Извади дисковото устройство.",
    "Unshare" : "Премахване на споделяне",
    "Could not load info for file \"{file}\"" : "Неуспешно зареждане на информация за файл \"{file}\"",
    "Files" : "Файлове",
    "Details" : "Подробности",
    "Select" : "Избери",
    "Pending" : "Чакащо",
    "Unable to determine date" : "Неуспешно установяване на дата",
    "Invalid path" : "Невалиден път",
    "This operation is forbidden" : "Операцията е забранена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директорията липсва, моля, проверете докладите или се свържете с администратора",
    "Could not move \"{file}\", target exists" : "Неуспешно преместване на  \"{file}\", крайната местоположение вече съществува",
    "Could not move \"{file}\"" : "Неуспешно преместване на \"{file}\"",
    "{newName} already exists" : "{newName} вече съществува",
    "Could not rename \"{fileName}\", it does not exist any more" : "Неуспешно преименуване на \"{fileName}\", вече не съществува",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{targetName}\" вече е заето в папка \"{dir}\". Моля, изберете друго име.",
    "Could not rename \"{fileName}\"" : "Неуспешно преименуване на \"{fileName}\"",
    "Could not create file \"{file}\"" : "Неуспешно създаване на \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Неуспешно създаване на \"{file}\", защото вече съществува",
    "Could not create folder \"{dir}\" because it already exists" : "Неуспешно създаване на папка \"{dir}\", защото вече съществува",
    "Error deleting file \"{fileName}\"." : "Грешка при изтриването на \"{fileName}\".",
    "Name" : "Име",
    "Size" : "Размер",
    "Modified" : "Променен на",
    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
    "_%n file_::_%n files_" : ["%n файл","%n файла"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["Включително %n скрит","Включително %n скрити"],
    "You don’t have permission to upload or create files here" : "Нямаш разрешение да създаваш или качваш файлове тук.",
    "_Uploading %n file_::_Uploading %n files_" : ["Качване на %n файл","Качване на %n файла."],
    "New" : "Създай",
    "\"{name}\" is an invalid file name." : "\"{name}\" е непозволено име за файл.",
    "File name cannot be empty." : "Името на файла не може да бъде оставено празно.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Дисковото пространство на {owner} е изчерпано, файлове не могат да бъдат обновявани или синхронизирани!",
    "Your storage is full, files can not be updated or synced anymore!" : "Заделеното място е запълнено, повече файлове не могат да бъдат синхронизирани или опреснени!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Дисковото пространство на {owner} е почити изчерпано ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Заделеното място е почити запълнено ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["пасва на '{filter}'","пасват на '{filter}'\n "],
    "Path" : "Път",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта"],
    "Favorited" : "Отбелязано в любими",
    "Favorite" : "Любими",
    "Folder" : "Папка",
    "New folder" : "Нова папка",
    "{newname} already exists" : "{newname} вече съществува",
    "Upload" : "Качване",
    "An error occurred while trying to update the tags" : "Настъпи грешка при опита за промяна на бележките",
    "A new file or folder has been <strong>created</strong>" : "Нов файл или папка беше <strong>създаден/а</strong>",
    "A file or folder has been <strong>changed</strong>" : "Файл или папка беше <strong>променен/а</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничване на известията за създаване и променяне на своите <strong>любими файлове</strong> <em>(Само в потока)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Файл или папка беше <strong>изтрит/а</strong>",
    "A file or folder has been <strong>restored</strong>" : "Файл или папка беше <strong>възстановен/а</strong>",
    "You created %1$s" : "Вие създадохте %1$s.",
    "%2$s created %1$s" : "%2$s създаде %1$s.",
    "%1$s was created in a public folder" : "%1$s е създаден в публична папка",
    "You changed %1$s" : "Вие променихте %1$s.",
    "%2$s changed %1$s" : "%2$s промени %1$s.",
    "You deleted %1$s" : "Вие изтрихте %1$s.",
    "%2$s deleted %1$s" : "%2$s изтри %1$s.",
    "You restored %1$s" : "Вие възстановихте %1$s",
    "%2$s restored %1$s" : "%2$s възстанови %1$s",
    "Changed by %2$s" : "Променен от %2$s",
    "Deleted by %2$s" : "Изтрит от %2$s",
    "Restored by %2$s" : "Възстановен от %2$s",
    "Upload (max. %s)" : "Качи (макс. %s)",
    "File handling" : "Операция с файла",
    "Maximum upload size" : "Максимален размер",
    "max. possible: " : "максимално:",
    "Save" : "Запис",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "С PHP-FPM може да отнеме 5 минути, за да бъдат приложени промените.",
    "Missing permissions to edit from here." : "Липсват права за промяна от тук.",
    "Settings" : "Настройки",
    "Show hidden files" : "Показване на скрити файлове",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Ползвайте този адрес за <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">достъп до файловете си през WebDAV</a>",
    "No files in here" : "Тук няма файлове",
    "Upload some content or sync with your devices!" : "Качи съдържание или синхронизирай с твоите устройства!",
    "No entries found in this folder" : "Няма намерени записи в тази папка",
    "Select all" : "Избери всички",
    "Upload too large" : "Прекалено голям файл за качване.",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файловете, които се опитваш да качиш са по-големи от позволеното на този сървър.",
    "No favorites" : "Няма любими",
    "Files and folders you mark as favorite will show up here" : "Файловете и папките които отбелязваш като любими ще се показват тук",
    "Text file" : "Текстов файл",
    "New text file.txt" : "Нов текст file.txt",
    "Target folder does not exist any more" : "Целевата папка вече не съществува",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Частна връзка: Само хората, които имат достъп до файла/папката, могат да я използват. Използвайте я като постоянна връзка за себе си или насочете другите към файлове които са споделени.",
    "Upload timeout for file \"{file}\"" : "Време за качване на файл \"{file}\"",
    "Processing files..." : "Файловете се обработват...",
    "No entries in this folder match {filter}" : "Нищо в тази папка не отговаря на {filter}",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "Ограничете известията за създаването и промените в <strong>любимите ви файлове </strong>",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Нямате разрешение за достъп до този файл папка - Моля, свържете се със собственика, за да го сподели с вас.",
    "Unknown user" : "Непознат потребител"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files/l10n/bg_BG.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Съхраняването е временно деактивирано",
    "Storage invalid" : "Невалидно дисково устройство.",
    "Unknown error" : "Непозната грешка.",
    "All files" : "Всички файлове",
    "File could not be found" : "Файлът не може да бъде открит",
    "Home" : "Домашен",
    "Close" : "Затвори",
    "Favorites" : "Любими",
    "Upload timeout for file \"{file}\"" : "Време за качване на файл \"{file}\"",
    "Unknown error \"{error}\" uploading file \"{file}\"" : "Неизвестна грешка \"{error}\" при качването на файл \"{file}\"",
    "Could not create folder \"{dir}\"" : "Неуспешно създаване на \"{dir}\"",
    "Upload cancelled." : "Качването е прекъснато.",
    "The file {file} already exists" : "Файлът {file} вече съществува",
    "Processing files..." : "Файловете се обработват...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неуспешно качване на {filename}, защото е директория или е с размер от 0 байта.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Няма достатъчно свободно място, ти се опитваш да качиш {size1}, но са останали само {size2}.",
    "Target folder \"{dir}\" does not exist any more" : "Целевата папка \"{dir}\" вече не съществува.",
    "Target folder does not exist any more" : "Целевата папка вече не съществува",
    "The file {file} is currently locked, please try again later" : "Файлът {file} е заключен, моля опитайте отново по-късно",
    "Not enough free space" : "Няма достатъчно свободно пространство",
    "Uploading..." : "Качване...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} от {totalSize} ({bitrate})",
    "Error when assembling chunks, status code {status}" : "Грешка при сглобяването на парчетата, код на състоянието {status}",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Извършва се качване на файлове. Затварянето на тази страница ще прекъсне качването.",
    "Actions" : "Действия",
    "Download" : "Изтегли",
    "Rename" : "Преименуване",
    "Delete" : "Изтрий",
    "Disconnect storage" : "Извади дисковото устройство.",
    "Unshare" : "Премахване на споделяне",
    "Could not load info for file \"{file}\"" : "Неуспешно зареждане на информация за файл \"{file}\"",
    "Files" : "Файлове",
    "Details" : "Подробности",
    "Select" : "Избери",
    "Pending" : "Чакащо",
    "Unable to determine date" : "Неуспешно установяване на дата",
    "Invalid path" : "Невалиден път",
    "This operation is forbidden" : "Операцията е забранена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директорията липсва, моля, проверете докладите или се свържете с администратора",
    "group" : "група",
    "Remote share" : "Прикачена Папка",
    "via" : "чрез",
    "Could not move \"{file}\", target exists" : "Неуспешно преместване на  \"{file}\", крайната местоположение вече съществува",
    "Could not move \"{file}\" because either the file or the target are locked." : "Не можа да се премести \"{file}\" защото или файлът, или целта са заключени.",
    "Could not move \"{file}\": {message}" : "Не може да се премести \"{file}\": {message}",
    "Could not move \"{file}\"" : "Неуспешно преместване на \"{file}\"",
    "{newName} already exists" : "{newName} вече съществува",
    "Could not rename \"{fileName}\", it does not exist any more" : "Неуспешно преименуване на \"{fileName}\", вече не съществува",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{targetName}\" вече е заето в папка \"{dir}\". Моля, изберете друго име.",
    "The file \"{fileName}\" is locked and can not be renamed." : "Файлът \"{fileName}\" е заключен и не може да бъде преименуван.",
    "Could not rename \"{fileName}\"" : "Неуспешно преименуване на \"{fileName}\"",
    "Could not create file \"{file}\"" : "Неуспешно създаване на \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Неуспешно създаване на \"{file}\", защото вече съществува",
    "Could not create folder \"{dir}\" because it already exists" : "Неуспешно създаване на папка \"{dir}\", защото вече съществува",
    "The file \"{fileName}\" is locked and cannot be deleted." : "Файлът \"{fileName}\" е заключен и не може да бъде изтрит.",
    "Error deleting file \"{fileName}\"." : "Грешка при изтриването на \"{fileName}\".",
    "No entries in this folder match {filter}" : "Нищо в тази папка не отговаря на {filter}",
    "Name" : "Име",
    "Size" : "Размер",
    "Modified" : "Променен на",
    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
    "_%n file_::_%n files_" : ["%n файл","%n файла"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["Включително %n скрит","Включително %n скрити"],
    "You don’t have permission to upload or create files here" : "Нямаш разрешение да създаваш или качваш файлове тук.",
    "_Uploading %n file_::_Uploading %n files_" : ["Качване на %n файл","Качване на %n файла."],
    "New" : "Създай",
    "Unknown user" : "Непознат потребител",
    "Lock status" : "Състояние заключен",
    "This resource is locked. Click to see more details." : "Този ресурс е заключен. Кликнете, за да видите повече подробности.",
    "\"{name}\" is an invalid file name." : "\"{name}\" е непозволено име за файл.",
    "File name cannot be empty." : "Името на файла не може да бъде оставено празно.",
    "File name cannot contain \"/\"." : "Името на файла не може да съдържа \"/\".",
    "\"{name}\" has a forbidden file type/extension." : "\"{name}\" има забранен тип/разширение на файла.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Дисковото пространство на {owner} е изчерпано, файлове не могат да бъдат обновявани или синхронизирани!",
    "Your storage is full, files can not be updated or synced anymore!" : "Заделеното място е запълнено, повече файлове не могат да бъдат синхронизирани или опреснени!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Дисковото пространство на {owner} е почити изчерпано ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Заделеното място е почити запълнено ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["пасва на '{filter}'","пасват на '{filter}'\n "],
    "{owner} has locked this resource via {path}" : "{owner} заключи този ресурс чрез {path}",
    "Could not unlock, please contact the lock owner {owner}" : "Не може да се отключи, моля свържете се със собственика на ключа {owner}",
    "Unlock failed with status {status}" : "Отключването не бе успешно със статус {status}",
    "Locks" : "Заключени",
    "Resource is not locked" : "Ресурсът не е заключен",
    "Path" : "Път",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта"],
    "Favorited" : "Отбелязано в любими",
    "Favorite" : "Любими",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "Частна връзка: Само хората, които имат достъп до файла/папката, могат да я използват. Използвайте я като постоянна връзка за себе си или насочете другите към файлове които са споделени.",
    "Folder" : "Папка",
    "New folder" : "Нова папка",
    "{newname} already exists" : "{newname} вече съществува",
    "Upload" : "Качване",
    "An error occurred while trying to update the tags" : "Настъпи грешка при опита за промяна на бележките",
    "A new file or folder has been <strong>created</strong>" : "Нов файл или папка беше <strong>създаден/а</strong>",
    "A file or folder has been <strong>changed</strong>" : "Файл или папка беше <strong>променен/а</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничване на известията за създаване и променяне на своите <strong>любими файлове</strong> <em>(Само в потока)</em>",
    "A file or folder has been <strong>deleted</strong>" : "Файл или папка беше <strong>изтрит/а</strong>",
    "A file or folder has been <strong>restored</strong>" : "Файл или папка беше <strong>възстановен/а</strong>",
    "You created %1$s" : "Вие създадохте %1$s.",
    "%2$s created %1$s" : "%2$s създаде %1$s.",
    "%1$s was created in a public folder" : "%1$s е създаден в публична папка",
    "You changed %1$s" : "Вие променихте %1$s.",
    "%2$s changed %1$s" : "%2$s промени %1$s.",
    "You deleted %1$s" : "Вие изтрихте %1$s.",
    "%2$s deleted %1$s" : "%2$s изтри %1$s.",
    "You restored %1$s" : "Вие възстановихте %1$s",
    "%2$s restored %1$s" : "%2$s възстанови %1$s",
    "Changed by %2$s" : "Променен от %2$s",
    "Deleted by %2$s" : "Изтрит от %2$s",
    "Restored by %2$s" : "Възстановен от %2$s",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "Нямате разрешение за достъп до този файл папка - Моля, свържете се със собственика, за да го сподели с вас.",
    "Upload (max. %s)" : "Качи (макс. %s)",
    "Settings" : "Настройки",
    "Show hidden files" : "Показване на скрити файлове",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Ползвайте този адрес за <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">достъп до файловете си през WebDAV</a>",
    "No files in here" : "Тук няма файлове",
    "Upload some content or sync with your devices!" : "Качи съдържание или синхронизирай с твоите устройства!",
    "No entries found in this folder" : "Няма намерени записи в тази папка",
    "Select all" : "Избери всички",
    "Upload too large" : "Прекалено голям файл за качване.",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файловете, които се опитваш да качиш са по-големи от позволеното на този сървър.",
    "No favorites" : "Няма любими",
    "Files and folders you mark as favorite will show up here" : "Файловете и папките които отбелязваш като любими ще се показват тук",
    "Text file" : "Текстов файл",
    "New text file.txt" : "Нов текст file.txt"
},
"nplurals=2; plural=(n != 1);");
